summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/chatmessagepart.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /kopete/kopete/chatwindow/chatmessagepart.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/kopete/chatwindow/chatmessagepart.h')
-rw-r--r--kopete/kopete/chatwindow/chatmessagepart.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kopete/kopete/chatwindow/chatmessagepart.h b/kopete/kopete/chatwindow/chatmessagepart.h
index ad14d3e3..5314d776 100644
--- a/kopete/kopete/chatwindow/chatmessagepart.h
+++ b/kopete/kopete/chatwindow/chatmessagepart.h
@@ -22,7 +22,7 @@
#include <khtml_part.h>
#include <dom/html_element.h>
-#include <qvaluelist.h>
+#include <tqvaluelist.h>
namespace Kopete
{
@@ -43,7 +43,7 @@ public:
/**
* Create a new ChatMessage Part.
*/
- ChatMessagePart( Kopete::ChatSession *manager, QWidget *parent, const char *name = 0);
+ ChatMessagePart( Kopete::ChatSession *manager, TQWidget *parent, const char *name = 0);
~ChatMessagePart();
/**
@@ -104,7 +104,7 @@ public slots:
*
* @param stylePath absolute path to the style.
*/
- void setStyle( const QString &stylePath );
+ void setStyle( const TQString &stylePath );
/**
* Change the current style
@@ -121,18 +121,18 @@ public slots:
* Change the current variant for the current style
* @param variantPath relative path to the style variant.
*/
- void setStyleVariant( const QString &variantPath );
+ void setStyleVariant( const TQString &variantPath );
signals:
/**
* Emits before the context menu is about to show
*/
- void contextMenuEvent( const QString &textUnderMouse, KPopupMenu *popupMenu );
+ void contextMenuEvent( const TQString &textUnderMouse, KPopupMenu *popupMenu );
/**
* Emits before the tooltip is about to show
*/
- void tooltipEvent( const QString &textUnderMouse, QString &toolTip );
+ void tooltipEvent( const TQString &textUnderMouse, TQString &toolTip );
private slots:
void slotOpenURLRequest( const KURL &url, const KParts::URLArgs &args );
@@ -143,7 +143,7 @@ private slots:
void slotRefreshView();
- void slotRightClick( const QString &, const QPoint &point );
+ void slotRightClick( const TQString &, const TQPoint &point );
void slotCopyURL();
@@ -170,49 +170,49 @@ protected:
private:
void readOverrides();
- const QString styleHTML() const;
+ const TQString styleHTML() const;
Kopete::Contact *contactFromNode( const DOM::Node &n ) const;
/**
* Emits before the tooltip is about to show
*/
- void emitTooltipEvent( const QString &textUnderMouse, QString &toolTipString );
+ void emitTooltipEvent( const TQString &textUnderMouse, TQString &toolTipString );
/**
* Returns the text currently under the mouse
*/
- QString textUnderMouse();
+ TQString textUnderMouse();
/**
* Format(replace) style keywords for messages (incoming, outgoing, internal)
* Use formatStyleKeywords(const QString &sourceHTML) for header and footer.
*
* @param sourceHTML the source html which contains the keywords
* @param message the current Message.
*
* @return the resulting HTML with replaced keywords.
*/
- QString formatStyleKeywords( const QString &sourceHTML, const Kopete::Message &message );
+ TQString formatStyleKeywords( const TQString &sourceHTML, const Kopete::Message &message );
/**
* Format(replace) style keywords for header and footers.
* For messages, use formatStyleKeywords(const QString &sourceHTML, Kopete::Message &message) instead.
*
* @param sourceHTML HTML source needed to be replaced.
*
* @return the resulting HTML with replaced keywords.
*/
- QString formatStyleKeywords( const QString &sourceHTML );
+ TQString formatStyleKeywords( const TQString &sourceHTML );
/**
* Helper function to parse time in correct format.
* Use glibc strftime function.
*
* @param timeFormat the time format to parse.
* @param dateTime the QDateTime which contains the datetime to format.
* @return the formatted time string.
*/
- QString formatTime(const QString &timeFormat, const QDateTime &dateTime);
+ TQString formatTime(const TQString &timeFormat, const TQDateTime &dateTime);
/**
* Format a nickname/displayname according to preferences.
@@ -220,7 +220,7 @@ private:
* @param sourceName Source name to format.
* @return the formatted name.
*/
- QString formatName( const QString &sourceName );
+ TQString formatName( const TQString &sourceName );
/**
* Format a message body according to the style included
@@ -229,7 +229,7 @@ private:
* @param message Kopete::Message to format.
* @return a span tag with a style attribute.
*/
- QString formatMessageBody( const Kopete::Message &message );
+ TQString formatMessageBody( const Kopete::Message &message );
/**
* Write the template file to KHTMLPart
@@ -170,49 +170,49 @@ protected:
/**
* Format(replace) style keywords for messages (incoming, outgoing, internal)
- * Use formatStyleKeywords(const QString &sourceHTML) for header and footer.
+ * Use formatStyleKeywords(const TQString &sourceHTML) for header and footer.
*
* @param sourceHTML the source html which contains the keywords
@@ -170,49 +170,49 @@ protected:
/**
* Format(replace) style keywords for header and footers.
- * For messages, use formatStyleKeywords(const QString &sourceHTML, Kopete::Message &message) instead.
+ * For messages, use formatStyleKeywords(const TQString &sourceHTML, Kopete::Message &message) instead.
*
* @param sourceHTML HTML source needed to be replaced.
@@ -170,49 +170,49 @@ protected:
*
* @param timeFormat the time format to parse.
- * @param dateTime the QDateTime which contains the datetime to format.
+ * @param dateTime the TQDateTime which contains the datetime to format.
* @return the formatted time string.
*/